@@ -743,7 +743,8 @@ class Client(Callbacks, SocketHandler):
             for listt in r:
                 com.append(listt["ndcId"])
             return com
-        else response.json()
+        else:
+            return response.json()
 
     def leave_chat(self, chatId: str):
         """
@@ -887,8 +888,24 @@ class Client(Callbacks, SocketHandler):
             - **Fail** : :meth:`Exceptions <amino.lib.util.exceptions>`
         """
         response = requests.get(f"{self.api}/g/s-x{comId}/community/info?withInfluencerList=1&withTopicList=true&influencerListOrderStrategy=fansCount", headers=self.parse_headers(), proxies=self.proxies, verify=self.certificatePath)
-        if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
+        if response.status_code != 200: return response.json()
         else: return objects.Community(json.loads(response.text)["community"]).Community
+    
+    def check_community(self, comId: str):
+        """
+        Information of an Community.
+
+        **Parameters**
+            - **comId** : ID of the Community.
+
+        **Returns**
+            - **Success** : :meth:`Community Object <amino.lib.util.objects.Community>`
+
+            - **Fail** : :meth:`Exceptions <amino.lib.util.exceptions>`
+        """
+        response = requests.get(f"{self.api}/g/s-x{comId}/community/info?withInfluencerList=1&withTopicList=true&influencerListOrderStrategy=fansCount", headers=self.parse_headers(), proxies=self.proxies, verify=self.certificatePath)
+        if response.status_code == 200: return response.json()["api:statuscode"]
+        else: return response.json()["api:statuscode"]
 
     def search_community(self, aminoId: str):
         """
